function varargout = SistemasEcuaciones(varargin)
% SISTEMASECUACIONES MATLAB code for SistemasEcuaciones.fig
%      SISTEMASECUACIONES, by itself, creates a new SISTEMASECUACIONES or raises the existing
%      singleton*.
%
%      H = SISTEMASECUACIONES returns the handle to a new SISTEMASECUACIONES or the handle to
%      the existing singleton*.
%
%      SISTEMASECUACIONES('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SISTEMASECUACIONES.M with the given input arguments.
%
%      SISTEMASECUACIONES('Property','Value',...) creates a new SISTEMASECUACIONES or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before SistemasEcuaciones_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to SistemasEcuaciones_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help SistemasEcuaciones

% Last Modified by GUIDE v2.5 10-Mar-2018 12:10:48

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @SistemasEcuaciones_OpeningFcn, ...
                   'gui_OutputFcn',  @SistemasEcuaciones_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before SistemasEcuaciones is made visible.
function SistemasEcuaciones_OpeningFcn(hObject, eventdata, handles, varargin)
A = imread('Imagen3.png');
image(A)
axis off

% Choose default command line output for SistemasEcuaciones
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes SistemasEcuaciones wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = SistemasEcuaciones_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
close(SistemasEcuaciones);
SE2x2

% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
close(SistemasEcuaciones);
SE3x3

% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
close(SistemasEcuaciones);
SE4x4

% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
close(SistemasEcuaciones);
SE5x5


% --- Executes on button press in pushbutton5.
function pushbutton5_Callback(hObject, eventdata, handles)
close(SistemasEcuaciones);
SE6x6

% --- Executes on button press in pushbutton6.
function pushbutton6_Callback(hObject, eventdata, handles)
close(SistemasEcuaciones);
SE7x7
